enum_start(neg_curve)
	enum_value (NEG_KODAK_ULTRA, "kodakultra", N_("Kodak Professional Ultra Endura"))
	enum_value (NEG_KODAK_PORTRA, "kodakportra", N_("Kodak Professional Portra Endura"))
	enum_value (NEG_KODAK_SUPRA, "kodaksupra", N_("Kodak Professional Supra Endura"))
	enum_value (NEG_KODAK_EKTACHROME, "kodakektachrome3", N_("Kodak Ektachrome Radiance III"))
	enum_value (NEG_FUJI, "fujicrystal", N_("Fujicolor Crystal Archive Digital Pearl Paper"))
	enum_value (NEG_ILFOBROM1, "ilfobrom1", N_("Ilford Ilfobrom Galerie FB 1"))
	enum_value (NEG_ILFOBROM2, "ilfobrom2", N_("Ilford Ilfobrom Galerie FB 2"))
	enum_value (NEG_ILFOBROM3, "ilfobrom3", N_("Ilford Ilfobrom Galerie FB 3"))
	enum_value (NEG_ILFOBROM4, "ilfobrom4", N_("Ilford Ilfobrom Galerie FB 4"))
	enum_value (NEG_ILFORDMG4, "ilfordmg4", N_("Ilford Multigrade IV RC Deluxe"))
	enum_value (NEG_FOMABROMC, "fomabromc", N_("Foma Fomabrom C"))
	enum_value (NEG_FOMABROMN, "fomabromn", N_("Foma Fomabrom N"))
	enum_value (NEG_FOMABROMSP, "fomabromsp", N_("Foma Fomabrom Sp"))
	enum_value (NEG_FOMABROMS, "fomabroms", N_("Foma Fomabrom S"))
	enum_value (NEG_FOMABROMVAR, "fomabromvar", N_("Foma Fomabrom Variant III"))
enum_end (NegCurve)
